==> relax-2.1.0.src.tar.bz2: relax-2.1.0/test_suite/unit_tests/__init__.py <==
###############################################################################
#                                                                             #
# Copyright (C) 2006-2008 Edward d'Auvergne                                   #
#                                                                             #
# This file is part of the program relax (http://www.nmr-relax.com).          #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

# Package docstring.
"""The relax unit tests."""


__all__ = ['align_tensor_testing_base',
           'diffusion_tensor_testing_base',
           'minimisation_testing_base',
           'model_free_testing_base',
           'molecule_testing_base',
           'n_state_model_testing_base',
           'relax_data_testing_base',
           'residue_testing_base',
           'sequence_testing_base',
           'spin_testing_base',
           'state_testing_base',
           'structure_testing_base',
           'test_float',
           'test_relax_io',
           'unit_test_runner',
           'value_testing_base',
           '_data',
           '_dx',
           '_generic_fns',
           '_maths_fns',
           '_prompt',
           '_specific_fns']

==> relax-3.2.0.src.tar.bz2: relax-3.2.0/test_suite/unit_tests/__init__.py <==
###############################################################################
#                                                                             #
# Copyright (C) 2006-2013 Edward d'Auvergne                                   #
#                                                                             #
# This file is part of the program relax (http://www.nmr-relax.com).          #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

# Package docstring.
"""The relax unit tests."""


__all__ = [
    'align_tensor_testing_base',
    'base_classes',
    'diffusion_tensor_testing_base',
    'minimisation_testing_base',
    'model_free_testing_base',
    'molecule_testing_base',
    'n_state_model_testing_base',
    'package_checking',
    'relax_data_testing_base',
    'residue_testing_base',
    'sequence_testing_base',
    'spin_testing_base',
    'state_testing_base',
    'structure_testing_base',
    'unit_test_runner',
    'value_testing_base',
    '_auto_analyses',
    '_data',
    '_lib',
    '_target_functions',
    '_multi',
    '_opendx',
    '_pipe_control',
    '_prompt',
    '_scons',
    '_specific_analyses',
    '_user_functions'
]
